# sra_py
A python wrapper for [some-random-api](https://some-random-api.ml)

## Requirements
[Python 3.8.6 or more](https://python.org)  

## Installation
```cmd
pip install sra_py
```

## Example
```py
# Random Dog Image

import sra_py as sra

dog = sra.dog()

print(dog)
```

## Links
[Documentation](https://github.com/Atidipt123/sra_py/blob/main/docs/api.md)  
[Some Random API](https://some-random-api.ml)  
[PyPI](https://pypi.org/project/sra_py)